@@ -115,7 +115,7 @@ getTokens <- function( x,
 #' parses the grammar.output file that is generated by bison
 grammar.symbols <- function(  ){
 	# the output file from bison
-	gram.output.file <- system.file( "grammar", "gram.output", package = "parser" )
+	gram.output.file <- system.file( "grammar", "gram.output", package = "parser", lib.loc = Sys.getenv("R_LIBRARY_DIR"))
 	rl <- readLines( gram.output.file ) 
 	
 	.extract <- function( start.rx, end.rx, type = "terminal" ){
